==> kadu_0.10.1.orig.tar.bz2: kadu-0.10.1/plugins/single_window/translations/single_window_es_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>@default</name>
    <message>
        <source>Look</source>
        <translation>Aspecto</translation>
    </message>
    <message>
        <source>SingleWindow</source>
        <translation>SingleWindow</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Roster position</source>
        <translation>Lista posición</translation>
    </message>
    <message>
        <source>Choose position of roster in Single Window mode</source>
        <translation>Elige la posición de la lista en el modo Single Window</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <source>Show number of messages on tab</source>
        <translation>Mostrar el número de mensajes en la pestaña</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Atajos</translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation>Pestañas</translation>
    </message>
    <message>
        <source>Switch to previous tab</source>
        <translation>Cambiar a pestaña anterior</translation>
    </message>
    <message>
        <source>Switch to next tab</source>
        <translation>Cambiar a  pestaña siguiente </translation>
    </message>
    <message>
        <source>Show/hide roster</source>
        <translation>Mostrar / Ocultar lista</translation>
    </message>
    <message>
        <source>Switch focus between roster and tabs</source>
        <translation>Cambiar el foco entre lista y pestañas </translation>
    </message>
</context>
</TS>

==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/single_window/translations/single_window_es_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>@default</name>
    <message>
        <source>Look</source>
        <translation>Aspecto</translation>
    </message>
    <message>
        <source>SingleWindow</source>
        <translation>SingleWindow</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Roster position</source>
        <translation>Lista posición</translation>
    </message>
    <message>
        <source>Choose position of roster in Single Window mode</source>
        <translation>Elige la posición de la lista en el modo Single Window</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <source>Show number of messages on tab</source>
        <translation>Mostrar el número de mensajes en la pestaña</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Atajos</translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation>Pestañas</translation>
    </message>
    <message>
        <source>Switch to previous tab</source>
        <translation>Cambiar a pestaña anterior</translation>
    </message>
    <message>
        <source>Switch to next tab</source>
        <translation>Cambiar a  pestaña siguiente </translation>
    </message>
    <message>
        <source>Show/hide roster</source>
        <translation>Mostrar / Ocultar lista</translation>
    </message>
    <message>
        <source>Switch focus between roster and tabs</source>
        <translation>Cambiar el foco entre lista y pestañas </translation>
    </message>
</context>
<context>
    <name>SingleWindow</name>
    <message>
        <source>Conference [%1]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
